==> qtmultimedia-opensource-src_5.7.0.orig.tar.xz: qtmultimedia-opensource-src-5.7.0/src/plugins/qnx-audio/audio/qnxaudioplugin.h <==
/****************************************************************************
**
** Copyright (C) 2016 Research In Motion
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QNXAUDIOPLUGIN_H
#define QNXAUDIOPLUGIN_H

#include <qaudiosystemplugin.h>

QT_BEGIN_NAMESPACE

class QnxAudioPlugin : public QAudioSystemPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.qt.audiosystemfactory/5.0" FILE "qnx_audio.json")

public:
    explicit QnxAudioPlugin(QObject *parent = 0);
    ~QnxAudioPlugin() {}

    QList<QByteArray> availableDevices(QAudio::Mode mode) const Q_DECL_OVERRIDE;
    QAbstractAudioInput *createInput(const QByteArray &device) Q_DECL_OVERRIDE;
    QAbstractAudioOutput *createOutput(const QByteArray &device) Q_DECL_OVERRIDE;
    QAbstractAudioDeviceInfo *createDeviceInfo(const QByteArray &device, QAudio::Mode mode) Q_DECL_OVERRIDE;
};

QT_END_NAMESPACE

#endif

==> qtmultimedia-opensource-src-5.9.4.tar.xz: qtmultimedia-opensource-src-5.9.4/src/plugins/qnx-audio/audio/qnxaudioplugin.h <==
/****************************************************************************
**
** Copyright (C) 2016 Research In Motion
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QNXAUDIOPLUGIN_H
#define QNXAUDIOPLUGIN_H

#include <QtMultimedia/qaudiosystemplugin.h>
#include <QtMultimedia/private/qaudiosystempluginext_p.h>

QT_BEGIN_NAMESPACE

class QnxAudioPlugin : public QAudioSystemPlugin, public QAudioSystemPluginExtension
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.qt.audiosystemfactory/5.0" FILE "qnx_audio.json")
    Q_INTERFACES(QAudioSystemPluginExtension)

public:
    explicit QnxAudioPlugin(QObject *parent = 0);
    ~QnxAudioPlugin() {}

    QByteArray defaultDevice(QAudio::Mode mode) const Q_DECL_OVERRIDE;
    QList<QByteArray> availableDevices(QAudio::Mode mode) const Q_DECL_OVERRIDE;
    QAbstractAudioInput *createInput(const QByteArray &device) Q_DECL_OVERRIDE;
    QAbstractAudioOutput *createOutput(const QByteArray &device) Q_DECL_OVERRIDE;
    QAbstractAudioDeviceInfo *createDeviceInfo(const QByteArray &device, QAudio::Mode mode) Q_DECL_OVERRIDE;
};

QT_END_NAMESPACE

#endif
